unit IFEngTst;
interface
uses
  IFEng;

type
  GLElementTest = class(GLElement)
  public
    function    GetVerbName(idx: integer): string; override;
{    procedure   ExecuteVerb(idx: integer); override;       }

    function    Clone: GLElement; override;
  end;

  GLElementBuilderTest = class(GLElementBuilder)
  private
    index:      integer;
    Elem0, Elem1, Elem2, Elem3, Elem4:      GLElementTest;
  public
    procedure   Open; override;
    procedure   Close; override;
    function    GetElementFirst: GLElement; override;
    function    GetElementNext: GLElement; override;
  end;

{=====================   implementation  ===================}
implementation
uses
  SysUtils;

{=====================   GLElementTests  ===================}
function GLElementTest.GetVerbName(idx: integer): string;
begin
  case idx of
    0: result := 'Execute';
    1: result := 'Edit';
    2: result := 'Translate';
    3: result := 'Randomize';
  else
    result := '';
  end;
end;

function GLElementTest.Clone: GLElement;
var i: integer;
begin
  result := GLElementTest.Create;
  i := 0;
  while (i < _props.Count) do begin
    result.AddProperty(GetPropertyByIndex(i).Clone);
    Inc(i);
  end;
end;

{=====================   Builder Functions   ===================}
procedure GLElementBuilderTest.Open;
begin
  Elem0 := GLElementTest.Create;
  Elem0.AddProperty(GLProperty.CreateAs(Str, 'page',   'Function', false, false));
  Elem0.AddProperty(GLProperty.CreateAs(Str, 'sheet',  'Simple', false, false));
  Elem0.AddProperty(GLProperty.CreateAs(Str, 'name',   'Add', true, false));
  Elem0.AddProperty(GLProperty.CreateAs(Str, 'image',  '', false, false));
  Elem0.AddProperty(GLProperty.CreateAs(Int, 'width',  '50', false, false));
  Elem0.AddProperty(GLProperty.CreateAs(Int, 'height', '50', false, false));
  Elem0.AddProperty(GLProperty.CreateAs(Int, 'param1', '1', true, true));
  Elem0.AddProperty(GLProperty.CreateAs(Int, 'param2', '2', true, true));
  Elem1 := GLElementTest.Create;
  Elem1.AddProperty(GLProperty.CreateAs(Str, 'page',   'Function', false, false));
  Elem1.AddProperty(GLProperty.CreateAs(Str, 'sheet',  'Simple', false, false));
  Elem1.AddProperty(GLProperty.CreateAs(Str, 'name',   'Sub', true, false));
  Elem1.AddProperty(GLProperty.CreateAs(Str, 'image',  '', false, false));
  Elem1.AddProperty(GLProperty.CreateAs(Int, 'width',  '50', false, false));
  Elem1.AddProperty(GLProperty.CreateAs(Int, 'height', '50', false, false));
  Elem2 := GLElementTest.Create;
  Elem2.AddProperty(GLProperty.CreateAs(Str, 'page',   'Function', false, false));
  Elem2.AddProperty(GLProperty.CreateAs(Str, 'sheet',  'Complex', false, false));
  Elem2.AddProperty(GLProperty.CreateAs(Str, 'name',   'Mul', true, false));
  Elem2.AddProperty(GLProperty.CreateAs(Str, 'image',  '', false, false));
  Elem2.AddProperty(GLProperty.CreateAs(Int, 'width',  '50', false, false));
  Elem2.AddProperty(GLProperty.CreateAs(Int, 'height', '50', false, false));
  Elem3 := GLElementTest.Create;
  Elem3.AddProperty(GLProperty.CreateAs(Str, 'page',   'Pipes', false, false));
  Elem3.AddProperty(GLProperty.CreateAs(Str, 'sheet',  'Standard', false, false));
  Elem3.AddProperty(GLProperty.CreateAs(Str, 'name',   'Pipe', true, false));
  Elem3.AddProperty(GLProperty.CreateAs(Str, 'image',  '', false, false));
  Elem3.AddProperty(GLProperty.CreateAs(Int, 'width',  '35', false, false));
  Elem3.AddProperty(GLProperty.CreateAs(Int, 'height', '50', false, false));
  Elem4 := GLElementTest.Create;
  Elem4.AddProperty(GLProperty.CreateAs(Str, 'page',   'Views', false, false));
  Elem4.AddProperty(GLProperty.CreateAs(Str, 'sheet',  'Standard', false, false));
  Elem4.AddProperty(GLProperty.CreateAs(Str, 'name',   'View', true, false));
  Elem4.AddProperty(GLProperty.CreateAs(Str, 'image',  '', false, false));
  Elem4.AddProperty(GLProperty.CreateAs(Int, 'width',  '60', false, false));
  Elem4.AddProperty(GLProperty.CreateAs(Int, 'height', '60', false, false));
end;

procedure GLElementBuilderTest.Close;
begin
  { empty : Elements handed off to caller }
end;

function GLElementBuilderTest.GetElementFirst: GLElement;
begin
  index := 1;
  result := Elem0;
end;

function GLElementBuilderTest.GetElementNext: GLElement;
begin
  case index of
    1:  result := Elem1;
    2:  result := Elem2;
    3:  result := Elem3;
    4:  result := Elem4;
  else
    result := nil;
  end;
  index := index + 1;
end;

end.


